/*
   Copyright 2009-2012 IEAP CTU
   Author: Daniel Turecek (daniel.turecek@utef.cvut.cz)
 */
package cz.ieap.jplugininterface.structs;

import cz.ieap.jplugininterface.PixelmanFuncsInterface;

/**
 * Class that contains indexes of dacs for medipix chips.
 *
 * @author Daniel Turecek
 * @version 1.0, 10/Aug/2010 14:44:55
 */
public class MpxDacs {

    // Medipix MXR
    public final static int MXR_COUNT = 15;
    public final static int MXR_IKRUM = 0;
    public final static int MXR_DISC = 1;
    public final static int MXR_PREAMP = 2;
    public final static int MXR_BUFFA = 3;
    public final static int MXR_BUFFB = 4;
    public final static int MXR_DELAYN = 5;
    public final static int MXR_THLFINE = 6;
    public final static int MXR_THLCOARSE = 7;
    public final static int MXR_THHFINE = 8;
    public final static int MXR_THHCOARSE = 9;
    public final static int MXR_FBK = 10;
    public final static int MXR_GND = 11;
    public final static int MXR_THS = 12;
    public final static int MXR_BIASLVDS = 13;
    public final static int MXR_REFLVDS = 14;

    // Timepix
    public final static int TPX_COUNT = 14;
    public final static int TPX_IKRUM = 0;
    public final static int TPX_DISC = 1;
    public final static int TPX_PREAMP = 2;
    public final static int TPX_BUFFA = 3;
    public final static int TPX_BUFFB = 4;
    public final static int TPX_HIST = 5;
    public final static int TPX_THLFINE = 6;
    public final static int TPX_THLCOARSE = 7;
    public final static int TPX_VCAS = 8;
    public final static int TPX_FBK = 9;
    public final static int TPX_GND = 10;
    public final static int TPX_THS = 11;
    public final static int TPX_BIASLVDS = 12;
    public final static int TPX_REFLVDS = 13;

    // Medipix3
    public final static int MPX3_COUNT = 25;
    public final static int MPX3_TH0 = 0;
    public final static int MPX3_TH1 = 1;
    public final static int MPX3_TH2 = 2;
    public final static int MPX3_TH3 = 3;
    public final static int MPX3_TH4 = 4;
    public final static int MPX3_TH5 = 5;
    public final static int MPX3_TH6 = 6;
    public final static int MPX3_TH7 = 7;
    public final static int MPX3_PREAMP = 8;
    public final static int MPX3_IKRUM = 9;
    public final static int MPX3_SHAPER = 10;
    public final static int MPX3_DISC = 11;
    public final static int MPX3_DISC_LS = 12;
    public final static int MPX3_TH_N = 13;
    public final static int MPX3_DAC_PIXEL = 14;
    public final static int MPX3_DELAY = 15;
    public final static int MPX3_TP_BUFF_IN = 16;
    public final static int MPX3_TP_BUFF_OUT = 17;
    public final static int MPX3_RPZ = 18;
    public final static int MPX3_GND = 19;
    public final static int MPX3_TP_REF = 20;
    public final static int MPX3_FBK = 21;
    public final static int MPX3_CAS = 22;
    public final static int MPX3_TP_REFA = 23;
    public final static int MPX3_TP_REFB = 24;

    // Medipix3 RX
    public final static int MPX3RX_COUNT = 27;
    public final static int MPX3RX_TH0 = 0;
    public final static int MPX3RX_TH1 = 1;
    public final static int MPX3RX_TH2 = 2;
    public final static int MPX3RX_TH3 = 3;
    public final static int MPX3RX_TH4 = 4;
    public final static int MPX3RX_TH5 = 5;
    public final static int MPX3RX_TH6 = 6;
    public final static int MPX3RX_TH7 = 7;
    public final static int MPX3RX_PREAMP = 8;
    public final static int MPX3RX_IKRUM = 9;
    public final static int MPX3RX_SHAPER = 10;
    public final static int MPX3RX_DISC = 11;
    public final static int MPX3RX_DISC_LS = 12;
    public final static int MPX3RX_SHAPER_TEST = 13;
    public final static int MPX3RX_DISC_L = 14;
    public final static int MPX3RX_TEST = 15;
    public final static int MPX3RX_DISC_H = 16;
    public final static int MPX3RX_DELAY = 17;
    public final static int MPX3RX_TP_BUFF_IN = 18;
    public final static int MPX3RX_TP_BUFF_OUT = 19;
    public final static int MPX3RX_RPZ = 20;
    public final static int MPX3RX_GND = 21;
    public final static int MPX3RX_TP_REF = 22;
    public final static int MPX3RX_FBK = 23;
    public final static int MPX3RX_CAS = 24;
    public final static int MPX3RX_TP_REFA = 25;
    public final static int MPX3RX_TP_REFB = 26;


    /**
     * Returns number of DACs according to passed type
     * @param mpxType Medipix type
     * @return number of DACs
     */
    public static int getDACsCount(int mpxType){
        switch (mpxType){
            case PixelmanFuncsInterface.MPX_MXR: return MXR_COUNT;
            case PixelmanFuncsInterface.MPX_TPX: return TPX_COUNT;
            case PixelmanFuncsInterface.MPX_3: return MPX3_COUNT;
            case PixelmanFuncsInterface.MPX_3RX: return MPX3RX_COUNT;
            default: return MXR_COUNT;
        }
    }
}
